ast\_toolbox.algos.backward\_algorithm module
=============================================

.. automodule:: ast_toolbox.algos.backward_algorithm
   :members:
   :undoc-members:
   :show-inheritance:
